@@ -129,18 +129,17 @@ def split_video_from_stamps(
             os.makedirs(tmp_output_dir.name, exist_ok=True)
             output_dirpath = tmp_output_dir.name
         output_dirpath = Path(output_dirpath)
-        for i, (s, e) in tqdm(
-                enumerate(zip(start_stamps, end_stamps)),
-                total=len(min(start_stamps, end_stamps)),
-                disable=show_progress is False):
+        for i, (s, e) in enumerate(zip(start_stamps, end_stamps)):
             start_frame = int(math.ceil(s * fps))
             end_frame = int(math.ceil(e * fps))
             output_paths.append(output_dirpath
                                 / filename_tmpl.format(
                                     start_frame=start_frame,
                                     end_frame=end_frame))
-    for i, (s, e, video_out) in enumerate(zip(start_stamps, end_stamps,
-                                              output_paths)):
+    for i, (s, e, video_out) in tqdm(enumerate(zip(
+            start_stamps, end_stamps, output_paths)),
+                                     total=len(output_paths),
+                                     disable=show_progress is False):
         split_video(video_file_path, video_out, start_time=s, end_time=e)
     return output_paths
 
